Basic structs using data from Cwtch and for deserializing JSON and serializing to JSON to communicate with Cwtch
Structs
AccessControl is a type determining client assigned authorization to a peer
Struct to deserialize the results of Get*Attribute requests into
Struct to serialize/deserialize conversations coming from libcwtch-go
Struct to serialize/deserialize events coming off the Cwtch appbus
Struct to serialize/deserialize messages sent over Cwtch between profiles / conversation
Struct to serialize/deserialize profiles coming from libcwtch-go
Struct to serialize/deserialize servers coming from libcwtch-go
Settings as defined in libcwtch-go/utils/settings.go and should be populated by handeling the UpdateGlobalSettings event emited during cwtch.start()
Enums
Defines the states a Cwtch connection can be in
Defines the various authorization modes a contact can be in
Enum of experiment types that can be managed in Settings
Enum matching message types and their overlays as defined in Cwtch
Type Definitions
represents an access control list for a conversation. Mapping handles to conversation functions